function JASApaper_figures

% This script reproduces many of the figures found in the journal paper:
% Y. Kopsinis, E. Aboutanios, D. A. Waters, S. McLaughlin, "Instantaneous
% Frequency - based Time-Frequency representation of multi-harmonic
% signals," Journal of Acoustical Society of America (JASA),
% vol. 127(2), Feb 2010.

% Feel free to use and modify the specific script. However, in case of
% publication the citation of the paper will be greatly
% appreciated.

%Also please note that if the bat calls supplied with these functions are
%used, then the above publication MUST be referenced.

% For questions and/or corrections email at kopsinis@ieee.org.




%% ***Call ppip00021_24n *******************************
[X,Fs,Nbits]=wavread([pwd,filesep,'pipistrellus_pipistrellus']);
% X(1:14000)=[];
Nf=1024;
Nt=length(X);
Ntpl=1500;
t=[1:Nt]/Fs;

% B = FIR1(100,0.05,'high');
% XX=filter(B,1,X);
% figure;plot(XX)

disp('Reproduction of Fig. 1(a)')
Nw=2^9+1;
[s,t,f]=STFT(X,Nw,2*Nf,Ntpl);
[l,c]=size(s);
topfreq=0.35;
ff=round(Nf*topfreq/0.5);
plotTFR(s(1:ff,:),t,f(1:ff)/1000,Fs,0.01,'P. pipistrellus, SPEC: 512 samples')



disp('Reproduction of Fig. 1(b)')
Nw=2^8+1;
[s,t,f]=STFT(X,Nw,2*Nf,Ntpl);
[l,c]=size(s);
topfreq=0.35;
ff=round(Nf*topfreq/0.5);
plotTFR(s(1:ff,:),t,f(1:ff),Fs,0.01,'P. pipistrellus, SPEC: 256 samples')



disp('Reproduction of Fig. 1(c)')
[X,Fs,Nbits]=wavread([pwd,filesep,'rhinolophus_capensis']);

Nf=1024;
Nt=1024;
t=[1:Nt]/Fs;
 
Nw=2^10+1;
[s,t,f]=STFT(X,Nw,2*Nf,Nt);
[l,c]=size(s);
topfreq=0.35;
ff=round(Nf*topfreq/0.5);
plotTFR(s(1:ff,:),t,f(1:ff),Fs,0.01,'R. capensis, SPEC: 1024 samples')


disp('Reproduction of Fig. 1(d)')
[X,Fs,Nbits]=wavread([pwd,filesep,'tadarida_aegyptiaca']);
Nf=1024;
Nt=1024;
%Ntpl=1024;
t=[1:Nt]/Fs;

Nw=2^10+1;
[s,t,f]=STFT(X,Nw,2*Nf,Nt);
[l,c]=size(s);
topfreq=0.13;
ff=round(Nf*topfreq/0.5);
plotTFR(s(1:ff,:),t,f(1:ff),Fs,0.5,'T. aegyptiaca, SPEC: 1024 samples')



disp('Reproduction of Fig. 3(a)')
[X,Fs,Nbits]=wavread([pwd,filesep,'pipistrellus_pipistrellus']);
% X(1:14000)=[];
Nf=1024;
Nt=length(X);
Ntpl=1500;
t=[1:Nt]/Fs;
Ng=201;
Nh=551;
[s,t,f]=SPECspwv(hilbert(X),Nf,Ntpl,Ng,Nh);
[l,c]=size(s);
topfreq=0.35;
ff=round(Nf*topfreq/0.5);
plotTFR(s(1:ff,:),t,f(1:ff),Fs,0.0001,'P. pipistrellus, SPWV: 201-551')


disp('Reproduction of Fig. 3(b)')
[X,Fs,Nbits]=wavread([pwd,filesep,'tadarida_aegyptiaca']);
Nf=1024;
Nt=1024;
Ng=491;
Nh=1001;
[s,t,f]=SPECspwv(hilbert(X),Nf,Nt,Ng,Nh);
[l,c]=size(s);
topfreq=0.13;
ff=round(Nf*topfreq/0.5);
plotTFR(s(1:ff,:),t,f(1:ff),Fs,0.002,'T. aegyptiaca, SPWV: 491-1001')


%% Figure 4


[X,Fs,Nbits]=wavread([pwd,filesep,'mixed_calls']);
Nf=1024;
%Nt=1024;
Ntpl=512;
%figure;plot(X)

disp('Reproduction of Fig. 4(a)')
Nw=2^10+1;
[s,t,f]=STFT(X,Nw,2*Nf,Ntpl);
[l,c]=size(s);
topfreq=0.15;
ff=round(Nf*topfreq/0.5);
nam=['SPEC, W=',num2str(Nw)];
plotTFR(s(1:ff,:),t,f(1:ff),Fs,0.3,nam)
%

disp('Reproduction of Fig. 4(b)')
M=30;
alpha=30;
topfreq=0.15;
[s,t,f,L]=MVE(X, Nf, Ntpl, M,alpha,topfreq);
[l,c]=size(s);
ff=round(Nf*topfreq/0.5);
nam=['MVE, M=',num2str(M),' a=',num2str(alpha)];
plotTFR(s(1:ff,:),t,f(1:ff),Fs,0.01,nam)

disp('Reproduction of Fig. 4(c)')
M=100;
alpha=30;
topfreq=0.15;
[s,t,f,L]=MVE(X, Nf, Ntpl, M,alpha,topfreq);
[l,c]=size(s);
ff=round(Nf*topfreq/0.5);
nam=['MVE, M=',num2str(M),' a=',num2str(alpha)];
plotTFR(s(1:ff,:),t,f(1:ff),Fs,0.01,nam)

disp('Reproduction of Fig. 4(d)')
M=100;
alpha=200;
topfreq=0.15;
[s,t,f,L]=MVE(X, Nf, Ntpl, M,alpha,topfreq);
[l,c]=size(s);
ff=round(Nf*topfreq/0.5);
nam=['MVE, M=',num2str(M),' a=',num2str(alpha)];
plotTFR(s(1:ff,:),t,f(1:ff),Fs,0.01,nam)

disp('Reproduction of Fig. 4(e)')
M=400;
alpha=30;
topfreq=0.15;
[s,t,f,L]=MVE(X, Nf, Ntpl, M,alpha,topfreq);
[l,c]=size(s);
ff=round(Nf*topfreq/0.5);
nam=['MVE, M=',num2str(M),' a=',num2str(alpha)];
plotTFR(s(1:ff,:),t,f(1:ff),Fs,0.01,nam)


disp('Reproduction of Fig. 4(g)')
[X,Fs,Nbits]=wavread([pwd,filesep,'tadarida_aegyptiaca']);
Nf=1024;
Nt=1024;
M=200;
alpha=30;
topfreq=0.15;
[s,t,f,L]=MVE(X, Nf, Ntpl, M,alpha,topfreq);
[l,c]=size(s);
ff=round(Nf*topfreq/0.5);
nam=['MVE, M=',num2str(M),' a=',num2str(alpha)];
plotTFR(s(1:ff,:),t,f(1:ff),Fs,0.05,nam)

disp('Reproduction of Fig. 4(h)')
[X,Fs,Nbits]=wavread([pwd,filesep,'rhinolophus_capensis']);
Nf=1024;
Nt=1024;
M=100;
alpha=60;
topfreq=0.35;
[s,t,f,L]=MVE(X, Nf, Ntpl, M,alpha,topfreq);
[l,c]=size(s);
ff=round(Nf*topfreq/0.5);
nam=['MVE, M=',num2str(M),' a=',num2str(alpha)];
plotTFR(s(1:ff,:),t,f(1:ff),Fs,0.0002,nam)


%% Figure 5
[X,Fs,Nbits]=wavread([pwd,filesep,'rhinolophus_capensis']);
disp('Reproduction of Fig. 5(e)')
Nf=1024;
Nt=length(X);
Ntpl=1500;
[IF,A]=IFIA(X);
topfreq=0.35;
dBval=1;
plotIF(IF',A',topfreq,Fs,dBval,'R. capensis, Hilbert spectrum')
disp('Reproduction of Fig. 5(f)')
smoothsamples=100;
orderofharmonic=2;
nofharmonics=4;
plotIFharmonics(IF',A',topfreq,Fs,dBval,smoothsamples,orderofharmonic,nofharmonics)

disp('')


%% Figure 6
[X,Fs,Nbits]=wavread([pwd,filesep,'pipistrellus_pipistrellus']);
disp('Reproduction of Fig. 6(a)')
Nf=1024;
Nt=length(X);
Ntpl=1500;

[IF,A]=IFIA(X);

topfreq=0.3;
dBval=1;
plotIF(IF',A',topfreq,Fs,dBval,'P. pipistrellus, Hilbert spectrum')

disp('Reproduction of Fig. 6(b)')
smoothsamples=100;
fundamental=1;
nofharmonics=3;
plotIFharmonics(IF',A',topfreq,Fs,dBval,smoothsamples,fundamental,nofharmonics)



end


