function plotIFharmonics(IFM,IA,ylimit,Fs,dbval,smoothsamples,orderofharmonic,nofharmonics)
% It plots a smoothed version of the Hilbert spectrum (see plotIF) and then
% the estimated harmonics

% IFM: Instantaneous Frequency
% IA: Instantaneous Amplitude
% ylimit: Takes a value between 0 and 0.5 and determines the maximum value
%         of the y-axis (i.e. the frequency) which is depicted. More
%         specifically, the maximum frequency shown is Fs*ylimit, where Fs
%         is the sampling frequency.
% Fs: Sampling frequency
% dbval: This value determines the dynamic range. Reducing this value enhances the visibility of
%        the lower energy components.
% smoothsamples: The number of samples that are used in a moving average
%                procedure for the IF smoothing 
% orderofharmonic: An integer number that indicates the order of the harmonic
%                  with instantaneous frequency IFM. For example, 1 refers
%                  to the fundamental, 2 to the second order harmonic (or the 1st overtone) etc.
% nofharmonics: The number of estimated harmonics that will be plotted. 

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% The script is written by Yannis Kopsinis & Elias Aboutanios for demonstration 
% purposes. Therefor, it might not be suitable in general signal cases and
% it is not optimised with respect to speed.

% For questions and/or corrections email at kopsinis@ieee.org.
% Feel free to use and modify the specific script. However, in case of
% publication the citation of the following paper will be greatly
% appreciated:

% Y. Kopsinis, E. Aboutanios, D. A. Waters, S. McLaughlin, "Instantaneous
% Frequency - based Time-Frequency representation of multi-harmonic
% signals," Journal of Acoustical Society of America (JASA),
% vol. 127(2), Feb 2010.
%
%Also please note that if the bat calls supplied with these functions are
%used, then the above publication MUST be referenced.




figure
IFM=IFM*Fs;
IFM=smooth(IFM,smoothsamples)';

t=[1:length(IFM)]/Fs;
ylimit=ylimit*Fs;
maxi=max(IA);
mini=max(min(IA),maxi*dbval/100);
indmin=find(IA<mini);
IA(indmin)=mini*ones(1,length(indmin));
indmax=find(IA>maxi);
IA(indmax)=maxi*ones(1,length(indmax));

IA=10*log10(IA);

% CM=colormap;
% CM=CM(1:2:end,:);
clmp=colormap('hot');
colormap(flipud(clmp));

CM=flipud(clmp); %colormap;
nofcolors=length(CM);

minA=min(min(IA));
maxA=max(max(IA));


interv=linspace(minA,maxA,nofcolors);
%interv(end)=1;
%figure
for modes=1:size(IFM,1)
    A=IA(modes,:);
    IF=IFM(modes,:)/1000;
plot(0,0)
hold on
set(gca,'color',CM(1,:))
for i=5:nofcolors
    [k1,k2]=find(A>=interv(i-1) & A<interv(i));
    k2(find(k2==1))=[];
    KK=diff(k2);
    KK(find(KK>1))=0;
    
    for j=1:length(k2)
        plot([t(k2(j)-1),t(k2(j))],[IF(k2(j)-1),IF(k2(j))],'color',CM(i,:))
    end
end
axis([0 t(end) 0 ylimit/1000])
drawnow

hold on
%lim2=5*(maxA-minA)/64;
IFM(find(A<interv(5)))=nan;

for i=1:nofharmonics+1
    if i~=orderofharmonic
        plot(t,(1/orderofharmonic)*i*IFM/1000,'g')
    end
end


drawnow
ylabel('Frequency (KHz)')
xlabel('Time')

end