function plotTFR(s,t,f,Fs,dbval,nam)
% Plots a time frequency representation.
% s: Matrix of the time frequency representation.
% t: Time instances (corresponding to the columns of s)
% F: Vector of normalized frequencies (corresponding to the lines of s)
% Fs: Sampling Frequency 
% dbval: Value determining the initial dynamic range. After the plot, the
%        dynamic range can be modified with slider existing in the produced
%        figure. Reducing this value enhances the visibility of the lower energy 
%        components of the time frequency representations.
% nam: The name that is given to the produced figure.

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% The script is written by Yannis Kopsinis & Elias Aboutanios for demonstration 
% purposes. Therefore, it might not be suitable in general signal cases and
% it is not optimised with respect to speed.

% For questions and/or corrections email at kopsinis@ieee.org.
% Feel free to use and modify the specific script. However, in case of
% publication the citation of the following paper will be greatly
% appreciated:

% Y. Kopsinis, E. Aboutanios, D. A. Waters, S. McLaughlin, "Instantaneous
% Frequency - based Time-Frequency representation of multi-harmonic
% signals," Journal of Acoustical Society of America (JASA),
% vol. 127(2), Feb 2010.

%Also please note that if the bat calls supplied with these functions are
%used, then the above publication MUST be referenced.


data.s=s;
data.t=t;
data.f=f;
data.Fs=Fs;
if nargin==5
fh = figure('Position',[250 250 350 350]);
else
    fh = figure('Position',[250 250 350 350],'name',nam);
end
ax1 = axes(...    % Axes for plotting the selected plot
    'Parent', fh, ...
    'Units', 'normalized', ...
    'HandleVisibility','callback', ...
    'Position',[0.11 0.13 0.80 0.67]);
sh = uicontrol(fh,'Style','slider',...
    'Max',60,'Min',0,'Value',dbval,...
    'SliderStep',[0.01 0.1],...
    'units','normalized',...
    'Position',[0.11 0.85 0.70 0.05],...
    'Callback',@slider_callback);
eth = uicontrol(fh,'Style','edit',...
    'String',num2str(get(sh,'Value')),...
    'units','normalized',...
    'Position',[0.81 0.85 0.1 0.05],...
    'Callback',@edittext_callback);
number_errors = 0;

% Set edit text UserData property to slider structure.

data.sliderval=dbval;

thres=data.sliderval;
maxi=max(max(s));
mini=max(min(min(s)),maxi*thres/100.0);
indmin=find(s<mini);
s(indmin)=mini*ones(1,length(indmin));
indmax=find(s>maxi);
s(indmax)=maxi*ones(1,length(indmax));

imagesc(t/Fs,f*Fs,10*log10(s),'parent',ax1)
data.typeofplot='imagesc';
axis('xy')
clmp=colormap('hot');
colormap(flipud(clmp));
set(fh,'UserData',data)
ylabel('Frequency (KHz)')
xlabel('Time')


% ----------------------------------------------------
% Set the value of the edit text component String property
% to the value of the slider.
    function slider_callback(hObject,eventdata)
        % Get slider from edit text UserData.
        data = get(fh,'UserData');
        sliderval = get(hObject,'Value');
        %%%%

        maxi=max(max(data.s));
        mini=max(min(min(data.s)),maxi*sliderval/100.0);
        indmin=find(data.s<mini);
        data.s(indmin)=mini*ones(1,length(indmin));
        indmax=find(data.s>maxi);
        data.s(indmax)=maxi*ones(1,length(indmax));

        imagesc(t/Fs,f*Fs,10*log10(data.s),'parent',ax1)
        axis('xy')
        set(eth,'String',num2str(sliderval));
        ylabel('Frequency (KHz)')
        xlabel('Time')

    end
% ----------------------------------------------------
% Set the slider value to the number the user types in
% the edit text or display an error message.
    function edittext_callback(hObject,eventdata)
        % Get slider from edit text UserData.
        data = get(fh,'UserData');
        sliderval = str2num(get(hObject,'string'));
        % Determine whether slider.val is a number between the
        % slider's Min and Max. If it is, set the slider Value.
        if isnumeric(sliderval) && ...
                length(sliderval) == 1 && ...
                sliderval >= get(sh,'Min') && ...
                sliderval <= get(sh,'Max')
            set(sh,'Value',sliderval);
            thres=sliderval;
            maxi=max(max(data.s));
            mini=max(min(min(data.s)),maxi*thres/100.0);
            indmin=find(data.s<mini);
            data.s(indmin)=mini*ones(1,length(indmin));
            indmax=find(data.s>maxi);
            data.s(indmax)=maxi*ones(1,length(indmax));
            imagesc(t/Fs,f*Fs,10*log10(data.s),'parent',ax1)
            axis('xy')
            ylabel('Frequency (KHz)')
            xlabel('Time')
        end

    end
end
